==> nextcloud-32.0.3-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/theming/l10n/de_DE.js <==
OC.L10N.register(
    "theming",
    {
    "The given name is too long" : "Der eingegebene Name ist zu lang",
    "The given web address is too long" : "Die eingegebene Internetadresse ist zu lang",
    "The given web address is not a valid URL" : "Die eingegebene Internetadresse ist keine gültige URL",
    "The given legal notice address is too long" : "Die im Impressum angegebene Adresse ist zu lang",
    "The given legal notice address is not a valid URL" : "Die eingegebene Impressums-Adresse ist keine gültige URL",
    "The given privacy policy address is too long" : "Die eingegebene Adresse der Datenschutzerklärung ist zu lang",
    "The given privacy policy address is not a valid URL" : "Die eingegebene Adresse der Datenschutzerklärung ist keine gültige URL",
    "The given slogan is too long" : "Der eingegebene Slogan ist zu lang",
    "The given color is invalid" : "Die gewählte Farbe ist ungültig",
    "Disable-user-theming should be true or false" : "Benutzer-Design deaktivieren sollte wahr oder falsch sein",
    "Saved" : "Gespeichert",
    "Invalid app given" : "Ungültige App angegeben",
    "Invalid type for setting \"defaultApp\" given" : "Ungültiger Typ für die Einstellung \"Standard-App\" angegeben",
    "Invalid setting key" : "Ungültiger Konfigurationsschlüssel",
    "The file was uploaded" : "Die Datei wurde hochgeladen",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "Die hochgeladene Datei überschreitet die upload_max_filesize-Vorgabe in php.ini",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "Die Datei ist größer, als die MAX_FILE_SIZE-Vorgabe erlaubt, die im HTML-Formular spezifiziert ist",
    "The file was only partially uploaded" : "Die Datei konnte nur teilweise hochgeladen werden",
    "No file was uploaded" : "Es wurde keine Datei hochgeladen",
    "Missing a temporary folder" : "Kein temporärer Ordner vorhanden",
    "Could not write file to disk" : "Die Datei konnte nicht auf die Festplatte geschrieben werden",
    "A PHP extension stopped the file upload" : "Eine PHP-Erweiterung hat das Hochladen der Datei gestoppt",
    "No file uploaded" : "Keine Datei hochgeladen",
    "You are already using a custom theme. Theming app settings might be overwritten by that." : "Sie benutzen bereits ein benutzerdefiniertes Design. Die Einstellungen dieser App könnten dadurch überschrieben werden.",
    "Theming" : "Design",
    "Appearance and accessibility" : "Aussehen und Barrierefreiheit",
    "PHP Imagick module" : "PHP Imagick-Modul",
    "The PHP module \"imagick\" is not enabled although the theming app is. For favicon generation to work correctly, you need to install and enable this module." : "Das PHP-Modul \"imagick\" ist nicht aktiviert, die Theming-App hingegen schon. Damit die Favicon-Generierung korrekt funktioniert, müssen Sie dieses Modul installieren und aktivieren.",
    "The PHP module \"imagick\" in this instance has no SVG support. For better compatibility it is recommended to install it." : "Das PHP-Modul \"imagick\" in dieser Instanz hat keine SVG-Unterstützung. Für eine bessere Kompatibilität empfiehlt es sich, es zu installieren.",
    "Dark theme with high contrast mode" : "Dunkles Design mit hohem Kontrast",
    "Enable dark high contrast mode" : "Kontrastreichen Modus (dunkel) aktivieren",
    "Similar to the high contrast mode, but with dark colours." : "Ähnlich wie das helle kontrastreiche Design, nur mit dunklen Farben.",
    "Dark theme" : "Dunkles Design",
    "Enable dark theme" : "Dunkles Design aktivieren",
    "A dark theme to ease your eyes by reducing the overall luminosity and brightness." : "Ein dunkles Design zur Entlastung der Augen durch Verringerung der Gesamtleuchtkraft und -helligkeit.",
    "System default theme" : "System-Design",
    "Enable the system default" : "System-Design aktivieren",
    "Using the default system appearance." : "Das Design des Systems übernehmen.",
    "Dyslexia font" : "Legasthenie-Schriftart",
    "Enable dyslexia font" : "Legasthenie-Schriftart aktivieren",
    "OpenDyslexic is a free typeface/font designed to mitigate some of the common reading errors caused by dyslexia." : "OpenDyslexic ist eine freie Schriftart, die entwickelt wurde, um einige der häufigsten Lesefehler, die durch Legasthenie verursacht werden, zu reduzieren.",
    "High contrast mode" : "Helles Design mit hohem Kontrast",
    "Enable high contrast mode" : "Kontrastreichen Modus (hell) aktivieren",
    "A high contrast mode to ease your navigation. Visual quality will be reduced but clarity will be increased." : "Ein kontrastreicher Modus, der die Navigation erleichtert. Die Bildqualität wird reduziert, die Übersichtlichkeit jedoch erhöht.",
    "Light theme" : "Helles Design",
    "Enable the default light theme" : "Helles Design aktivieren",
    "The default light appearance." : "Das helle Standarddesign.",
    "Legal notice" : "Impressum",
    "Privacy policy" : "Datenschutzerklärung",
    "Adjust the Nextcloud theme" : "Passen Sie das Design von Nextcloud an",
    "Name" : "Name",
    "Web link" : "Internet-Link",
    "a safe home for all your data" : "Ein sicheres Zuhause für Ihre Daten",
    "Slogan" : "Slogan",
    "Primary color" : "Primärfarbe",
    "The primary color is used for highlighting elements like important buttons. It might get slightly adjusted depending on the current color schema." : "Die Primärfarbe wird zum Hervorheben von Elementen wie wichtigen Schaltflächen verwendet. Sie kann je nach aktuellem Farbschema leicht angepasst werden.",
    "Legal notice link" : "Link zum Impressum",
    "Privacy policy link" : "Link zur Datenschutzerklärung",
    "Header logo" : "Kopfbereichs-Logo",
    "Upload new header logo" : "Neues Logo für den Kopfbereich hochladen",
    "Favicon" : "Favicon",
    "Upload new favicon" : "Neues Favicon hochladen",
    "User settings" : "Benutzer-Einstellungen",
    "Disable user theming" : "Benutzer-Design deaktivieren",
    "Although you can select and customize your instance, users can change their background and colors. If you want to enforce your customization, you can toggle this on." : "Trotz der von Ihnen vorgenommenen Auswahl und Anpassung können Benutzer ihren Hintergrund und ihre Farben ändern. Wenn Sie Ihre Anpassung erzwingen möchten, können Sie dies hier aktivieren.",
    "Theming makes it possible to easily customize the look and feel of your instance and supported clients. This will be visible for all users." : "Das Ändern des Designs ermöglicht es auf einfache Weise, das Aussehen Ihrer Installation und Clients anzupassen. Die Änderungen wirken sich auf alle Benutzer aus.",
    "Instead of a background image you can also configure a plain background color. If you use a background image changing this color will influence the color of the app menu icons." : "Anstelle eines Hintergrundbildes können Sie auch eine einfache Hintergrundfarbe konfigurieren. Wenn Sie ein Hintergrundbild verwenden, wirkt sich die Änderung dieser Farbe auf die Farbe der App-Menüsymbole aus.",
    "Background color" : "Hintergrundfarbe",
    "Upload new logo" : "Neues Logo hochladen",
    "Logo" : "Logo",
    "Upload new background and login image" : "Ein neues Hintergrund- und Anmeldebild hochladen",
    "Background and login image" : "Hintergrund und Anmeldebild",
    "Advanced options" : "Erweiterte Optionen",
    "Install the ImageMagick PHP extension with support for SVG images to automatically generate favicons based on the uploaded logo and color." : "Installieren Sie die ImageMagick PHP-Erweiterung mit Unterstützung für SVG-Bilder, um automatisch Favicons auf Basis des hochgeladenen Logos und der Farbe zu erstellen.",
    "Universal access is very important to us. We follow web standards and check to make everything usable also without mouse, and assistive software such as screenreaders. We aim to be compliant with the {linkstart}Web Content Accessibility Guidelines{linkend} 2.1 on AA level, with the high contrast theme even on AAA level." : "Der barrierefreie Zugang ist für uns sehr wichtig. Wir halten uns an Webstandards und prüfen, ob alles auch ohne Maus und unterstützende Software wie Screenreader nutzbar ist. Wir streben die Einhaltung der {linkstart}Web Content Accessibility Guidelines{linkend} 2.1 auf AA-Niveau an, mit dem kontrastreichen Design sogar auf AAA-Niveau.",
    "If you find any issues, do not hesitate to report them on {issuetracker}our issue tracker{linkend}. And if you want to get involved, come join {designteam}our design team{linkend}!" : "Wenn Sie Fehler finden, melden Sie diese bitte in {issuetracker}unserem Issue Tracker{linkend}. Und wenn Sie mithelfen möchten, treten Sie dem {designteam}Designteam{linkend} bei!",
    "Unable to apply the setting." : "Die Einstellung kann nicht übernommen werden.",
    "Appearance and accessibility settings" : "Einstellungen zu Aussehen und Barrierefreiheit",
    "Misc accessibility options" : "Verschiedene Barrierefreiheitsoptionen",
    "Enable blur background filter (may increase GPU load)" : "Filter für unscharfes Hintergrundbild aktivieren (kann die GPU-Auslastung erhöhen)",
    "Customization has been disabled by your administrator" : "Diese Anpassungsmöglichkeit wurde von Ihrer Administration deaktiviert",
    "Set a primary color to highlight important elements. The color used for elements such as primary buttons might differ a bit as it gets adjusted to fulfill accessibility requirements." : "Legen Sie eine Primärfarbe fest, um wichtige Elemente hervorzuheben. Die für Elemente wie Primärschaltflächen verwendete Farbe kann etwas abweichen, da sie angepasst wird, um die Zugänglichkeitsanforderungen zu erfüllen.",
    "Background and color" : "Hintergrund und Farbe",
    "The background can be set to an image from the default set, a custom uploaded image, or a plain color." : "Als Hintergrund kann ein Bild aus dem Standardsatz, ein benutzerdefiniertes hochgeladenes Bild oder eine einfache Farbe ausgewählt werden.",
    "Keyboard shortcuts" : "Tastaturkürzel",
    "In some cases keyboard shortcuts can interfere with accessibility tools. In order to allow focusing on your tool correctly you can disable all keyboard shortcuts here. This will also disable all available shortcuts in apps." : "In einigen Fällen können Tastaturkürzel Barrierefreiheits-Tools beeinträchtigen. Damit Sie sich richtig auf Ihr Werkzeug konzentrieren können, können Sie hier alle Tastaturkürzel deaktivieren. Dadurch werden auch alle verfügbaren Verknüpfungen in Apps deaktiviert.",
    "Disable all keyboard shortcuts" : "Alle Tastaturkürzel deaktivieren",
    "Current selected app: {app}, position {position} of {total}" : "Aktuell ausgewählte App: {app}, Position {position} von {total}",
    "Move up" : "Nach oben verschieben",
    "Move down" : "Nach unten verschieben",
    "Select a background from your files" : "Wählen Sie einen Hintergrund aus Ihren Dateien",
    "Select background" : "Hintergrund wählen",
    "No background has been selected" : "Es wurde kein Hintergrund ausgewählt",
    "Custom background" : "Benutzerdefinierter Hintergrund",
    "Plain background" : "Einfarbiger Hintergrund",
    "Default background" : "Standardhintergrund",
    "Theme selection is enforced" : "Designauswahl wird erzwungen",
    "Could not set the app order" : "Die App-Reihenfolge konnte nicht festgelegt werden",
    "Could not reset the app order" : "Standard-App-Reihenfolge konnte nicht zurückgesetzt werden",
    "Navigation bar settings" : "Einstellungen der Navigationsleiste",
    "You can configure the app order used for the navigation bar. The first entry will be the default app, opened after login or when clicking on the logo." : "Sie können die App-Reihenfolge für die Navigationsleiste konfigurieren. Der erste Eintrag ist die Standard-App, die nach der Anmeldung oder beim Klicken auf das Logo geöffnet wird.",
    "The default app can not be changed because it was configured by the administrator." : "Die Standard-App kann nicht geändert werden, da sie von der Administration konfiguriert wurde.",
    "The app order was changed, to see it in action you have to reload the page." : "Die App-Reihenfolge wurde geändert. Um die Änderungen zu sehen, müssen Sie die Seite neu laden.",
    "Reset default app order" : "Standard-App-Reihenfolge zurücksetzen",
    "Could not set primary color" : "Primärfarbe konnte nicht festgelegt werden",
    "Reset primary color" : "Primärfarbe zurücksetzen",
    "Could not set global default apps" : "Globale Standard-Apps konnten nicht festgelegt werden",
    "Default app" : "Standard-App",
    "The default app is the app that is e.g. opened after login or when the logo in the menu is clicked." : "Die Standard-App ist die App, die z. B. nach der Anmeldung oder nach Klicken auf das Logo im Menü geöffnet wird.",
    "Use custom default app" : "Benutzerdefinierte Standard-App verwenden",
    "Global default app" : "Globale Standard-App",
    "Global default apps" : "Globale Standard-Apps",
    "Default app priority" : "Standard-App-Priorität",
    "If an app is not enabled for a user, the next app with lower priority is used." : "Wenn eine App für einen Benutzer nicht aktiviert ist, wird die nächste App mit niedrigerer Priorität verwendet.",
    "Select a custom color" : "Eine benutzerdefinierte Farbe auswählen",
    "Reset to default" : "Auf Standard zurücksetzen ",
    "Upload" : "Hochladen",
    "Remove background image" : "Hintergrundbild entfernen",
    "Universal access is very important to us. We follow web standards and check to make everything usable also without mouse, and assistive software such as screenreaders. We aim to be compliant with the {guidelines}Web Content Accessibility Guidelines{linkend} 2.1 on AA level, with the high contrast theme even on AAA level." : "Der barrierefreie Zugang ist für uns sehr wichtig. Wir halten uns an Webstandards und prüfen, ob alles auch ohne Maus und unterstützende Software wie Screenreader nutzbar ist. Wir streben die Einhaltung der {guidelines}Web Content Accessibility Guidelines{linkend} 2.1 auf AA-Niveau an, mit dem kontrastreichen Design sogar auf AAA-Niveau.",
    ". Unable to apply the setting." : ". Fehler beim Anwenden der Einstellung."
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-32.0.5-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/theming/l10n/de_DE.js <==
OC.L10N.register(
    "theming",
    {
    "The given name is too long" : "Der eingegebene Name ist zu lang",
    "The given web address is too long" : "Die eingegebene Internetadresse ist zu lang",
    "The given web address is not a valid URL" : "Die eingegebene Internetadresse ist keine gültige URL",
    "The given legal notice address is too long" : "Die im Impressum angegebene Adresse ist zu lang",
    "The given legal notice address is not a valid URL" : "Die eingegebene Impressums-Adresse ist keine gültige URL",
    "The given privacy policy address is too long" : "Die eingegebene Adresse der Datenschutzerklärung ist zu lang",
    "The given privacy policy address is not a valid URL" : "Die eingegebene Adresse der Datenschutzerklärung ist keine gültige URL",
    "The given slogan is too long" : "Der eingegebene Slogan ist zu lang",
    "The given color is invalid" : "Die gewählte Farbe ist ungültig",
    "%1$s should be true or false" : "%1$s muss wahr oder falsch sein",
    "%1$s can only be set to %2$s through the API" : "%1$s kann nur über die API auf %2$s gesetzt werden",
    "Invalid setting key" : "Ungültiger Konfigurationsschlüssel",
    "Saved" : "Gespeichert",
    "Invalid app given" : "Ungültige App angegeben",
    "Invalid type for setting \"defaultApp\" given" : "Ungültiger Typ für die Einstellung \"Standard-App\" angegeben",
    "The file was uploaded" : "Die Datei wurde hochgeladen",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "Die hochgeladene Datei überschreitet die upload_max_filesize-Vorgabe in php.ini",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "Die Datei ist größer, als die MAX_FILE_SIZE-Vorgabe erlaubt, die im HTML-Formular spezifiziert ist",
    "The file was only partially uploaded" : "Die Datei konnte nur teilweise hochgeladen werden",
    "No file was uploaded" : "Es wurde keine Datei hochgeladen",
    "Missing a temporary folder" : "Kein temporärer Ordner vorhanden",
    "Could not write file to disk" : "Die Datei konnte nicht auf die Festplatte geschrieben werden",
    "A PHP extension stopped the file upload" : "Eine PHP-Erweiterung hat das Hochladen der Datei gestoppt",
    "No file uploaded" : "Keine Datei hochgeladen",
    "You are already using a custom theme. Theming app settings might be overwritten by that." : "Sie benutzen bereits ein benutzerdefiniertes Design. Die Einstellungen dieser App könnten dadurch überschrieben werden.",
    "Theming" : "Design",
    "Appearance and accessibility" : "Aussehen und Barrierefreiheit",
    "PHP Imagick module" : "PHP Imagick-Modul",
    "The PHP module \"imagick\" is not enabled although the theming app is. For favicon generation to work correctly, you need to install and enable this module." : "Das PHP-Modul \"imagick\" ist nicht aktiviert, die Theming-App hingegen schon. Damit die Favicon-Generierung korrekt funktioniert, müssen Sie dieses Modul installieren und aktivieren.",
    "The PHP module \"imagick\" in this instance has no SVG support. For better compatibility it is recommended to install it." : "Das PHP-Modul \"imagick\" in dieser Instanz hat keine SVG-Unterstützung. Für eine bessere Kompatibilität empfiehlt es sich, es zu installieren.",
    "Dark theme with high contrast mode" : "Dunkles Design mit hohem Kontrast",
    "Enable dark high contrast mode" : "Kontrastreichen Modus (dunkel) aktivieren",
    "Similar to the high contrast mode, but with dark colours." : "Ähnlich wie das helle kontrastreiche Design, nur mit dunklen Farben.",
    "Dark theme" : "Dunkles Design",
    "Enable dark theme" : "Dunkles Design aktivieren",
    "A dark theme to ease your eyes by reducing the overall luminosity and brightness." : "Ein dunkles Design zur Entlastung der Augen durch Verringerung der Gesamtleuchtkraft und -helligkeit.",
    "System default theme" : "System-Design",
    "Enable the system default" : "System-Design aktivieren",
    "Using the default system appearance." : "Das Design des Systems übernehmen.",
    "Dyslexia font" : "Legasthenie-Schriftart",
    "Enable dyslexia font" : "Legasthenie-Schriftart aktivieren",
    "OpenDyslexic is a free typeface/font designed to mitigate some of the common reading errors caused by dyslexia." : "OpenDyslexic ist eine freie Schriftart, die entwickelt wurde, um einige der häufigsten Lesefehler, die durch Legasthenie verursacht werden, zu reduzieren.",
    "High contrast mode" : "Helles Design mit hohem Kontrast",
    "Enable high contrast mode" : "Kontrastreichen Modus (hell) aktivieren",
    "A high contrast mode to ease your navigation. Visual quality will be reduced but clarity will be increased." : "Ein kontrastreicher Modus, der die Navigation erleichtert. Die Bildqualität wird reduziert, die Übersichtlichkeit jedoch erhöht.",
    "Light theme" : "Helles Design",
    "Enable the default light theme" : "Helles Design aktivieren",
    "The default light appearance." : "Das helle Standarddesign.",
    "Legal notice" : "Impressum",
    "Privacy policy" : "Datenschutzerklärung",
    "Adjust the Nextcloud theme" : "Passen Sie das Design von Nextcloud an",
    "Could not set global default apps" : "Globale Standard-Apps konnten nicht festgelegt werden",
    "Navigation bar settings" : "Einstellungen der Navigationsleiste",
    "Default app" : "Standard-App",
    "The default app is the app that is e.g. opened after login or when the logo in the menu is clicked." : "Die Standard-App ist die App, die z. B. nach der Anmeldung oder nach Klicken auf das Logo im Menü geöffnet wird.",
    "Use custom default app" : "Benutzerdefinierte Standard-App verwenden",
    "Global default app" : "Globale Standard-App",
    "Global default apps" : "Globale Standard-Apps",
    "Default app priority" : "Standard-App-Priorität",
    "If an app is not enabled for a user, the next app with lower priority is used." : "Wenn eine App für einen Benutzer nicht aktiviert ist, wird die nächste App mit niedrigerer Priorität verwendet.",
    "Theming makes it possible to easily customize the look and feel of your instance and supported clients. This will be visible for all users." : "Das Ändern des Designs ermöglicht es auf einfache Weise, das Aussehen Ihrer Installation und Clients anzupassen. Die Änderungen wirken sich auf alle Benutzer aus.",
    "Name" : "Name",
    "Web link" : "Internet-Link",
    "Slogan" : "Slogan",
    "a safe home for all your data" : "Ein sicheres Zuhause für Ihre Daten",
    "Legal notice link" : "Link zum Impressum",
    "Privacy policy link" : "Link zur Datenschutzerklärung",
    "Background and color" : "Hintergrund und Farbe",
    "Primary color" : "Primärfarbe",
    "Set the default primary color, used to highlight important elements." : "Die Standard-Primärfarbe festlegen, die zum Hervorheben wichtiger Elemente verwendet wird.",
    "The color used for elements such as primary buttons might differ a bit as it gets adjusted to fulfill accessibility requirements." : "Die für Elemente wie Primär-Buttons verwendete Farbe kann etwas abweichen, wenn diese an die Barrierefreiheitsanforderungen angepasst wird.",
    "Background color" : "Hintergrundfarbe",
    "When no background image is set the background color will be used." : "Sofern kein Hintergrundbild eingestellt ist, wird die Hintergrundfarbe verwendet.",
    "Otherwise the background color is by default generated from the background image, but can be adjusted to fine tune the color of the navigation icons." : "Andernfalls wird die Hintergrundfarbe standardmäßig aus dem Hintergrundbild generiert, kann aber angepasst werden, um die Farbe der Navigationssymbole darauf abzustimmen.",
    "Use a plain background color instead of a background image." : "Eine einfache Hintergrundfarbe anstelle eines Hintergrundbildes verwenden.",
    "Remove background image" : "Hintergrundbild entfernen",
    "Background image" : "Hintergrundbild",
    "Favicon" : "Favicon",
    "Logo" : "Logo",
    "Navigation bar logo" : "Navigationsleisten-Logo",
    "Although you can select and customize your instance, users can change their background and colors. If you want to enforce your customization, you can toggle this on." : "Trotz der von Ihnen vorgenommenen Auswahl und Anpassung können Benutzer ihren Hintergrund und ihre Farben ändern. Wenn Sie Ihre Anpassung erzwingen möchten, können Sie dies hier aktivieren.",
    "Disable user theming" : "Benutzer-Design deaktivieren",
    "Current selected app: {app}, position {position} of {total}" : "Aktuell ausgewählte App: {app}, Position {position} von {total}",
    "Navigation bar app order" : "Reihenfolge der Navigationsleisten-App",
    "Move up" : "Nach oben verschieben",
    "Move down" : "Nach unten verschieben",
    "Theme selection is enforced" : "Designauswahl wird erzwungen",
    "Could not set the app order" : "Die App-Reihenfolge konnte nicht festgelegt werden",
    "Could not reset the app order" : "Standard-App-Reihenfolge konnte nicht zurückgesetzt werden",
    "You can configure the app order used for the navigation bar. The first entry will be the default app, opened after login or when clicking on the logo." : "Sie können die App-Reihenfolge für die Navigationsleiste konfigurieren. Der erste Eintrag ist die Standard-App, die nach der Anmeldung oder beim Klicken auf das Logo geöffnet wird.",
    "The default app can not be changed because it was configured by the administrator." : "Die Standard-App kann nicht geändert werden, da sie von der Administration konfiguriert wurde.",
    "The app order was changed, to see it in action you have to reload the page." : "Die App-Reihenfolge wurde geändert. Um die Änderungen zu sehen, müssen Sie die Seite neu laden.",
    "Reset default app order" : "Standard-App-Reihenfolge zurücksetzen",
    "Select a background from your files" : "Wählen Sie einen Hintergrund aus Ihren Dateien",
    "Select background" : "Hintergrund wählen",
    "The background can be set to an image from the default set, a custom uploaded image, or a plain color." : "Als Hintergrund kann ein Bild aus dem Standardsatz, ein benutzerdefiniertes hochgeladenes Bild oder eine einfache Farbe ausgewählt werden.",
    "Custom background" : "Benutzerdefinierter Hintergrund",
    "Plain background" : "Einfarbiger Hintergrund",
    "Default background" : "Standardhintergrund",
    "Default shipped background images" : "Standardmäßig mitgelieferte Hintergrundbilder",
    "Keyboard shortcuts" : "Tastaturkürzel",
    "In some cases keyboard shortcuts can interfere with accessibility tools. In order to allow focusing on your tool correctly you can disable all keyboard shortcuts here. This will also disable all available shortcuts in apps." : "In einigen Fällen können Tastaturkürzel Barrierefreiheits-Tools beeinträchtigen. Damit Sie sich richtig auf Ihr Werkzeug konzentrieren können, können Sie hier alle Tastaturkürzel deaktivieren. Dadurch werden auch alle verfügbaren Verknüpfungen in Apps deaktiviert.",
    "Disable all keyboard shortcuts" : "Alle Tastaturkürzel deaktivieren",
    "Could not set primary color" : "Primärfarbe konnte nicht festgelegt werden",
    "Set a primary color to highlight important elements. The color used for elements such as primary buttons might differ a bit as it gets adjusted to fulfill accessibility requirements." : "Legen Sie eine Primärfarbe fest, um wichtige Elemente hervorzuheben. Die für Elemente wie Primärschaltflächen verwendete Farbe kann etwas abweichen, da sie angepasst wird, um die Barrierefreiheitsanforderungen zu erfüllen.",
    "Reset primary color" : "Primärfarbe zurücksetzen",
    "Reset to default" : "Auf Standard zurücksetzen ",
    "Non image file selected" : "Keine Bilddatei ausgewählt",
    "Preview of the selected image" : "Vorschau des ausgewählten Bildes",
    "Universal access is very important to us. We follow web standards and check to make everything usable also without mouse, and assistive software such as screenreaders. We aim to be compliant with the {linkstart}Web Content Accessibility Guidelines{linkend} 2.1 on AA level, with the high contrast theme even on AAA level." : "Der barrierefreie Zugang ist für uns sehr wichtig. Wir halten uns an Webstandards und prüfen, ob alles auch ohne Maus und unterstützende Software wie Screenreader nutzbar ist. Wir streben die Einhaltung der {linkstart}Web Content Accessibility Guidelines{linkend} 2.1 auf AA-Niveau an, mit dem kontrastreichen Design sogar auf AAA-Niveau.",
    "If you find any issues, do not hesitate to report them on {issuetracker}our issue tracker{linkend}. And if you want to get involved, come join {designteam}our design team{linkend}!" : "Wenn Sie Fehler finden, melden Sie diese bitte in {issuetracker}unserem Issue Tracker{linkend}. Und wenn Sie mithelfen möchten, treten Sie dem {designteam}Designteam{linkend} bei!",
    "Unable to apply the setting." : "Die Einstellung kann nicht übernommen werden.",
    "Appearance and accessibility settings" : "Einstellungen zu Aussehen und Barrierefreiheit",
    "Misc accessibility options" : "Verschiedene Barrierefreiheitsoptionen",
    "Enable blur background filter (may increase GPU load)" : "Filter für unscharfes Hintergrundbild aktivieren (kann die GPU-Auslastung erhöhen)",
    "Customization has been disabled by your administrator" : "Diese Anpassungsmöglichkeit wurde von Ihrer Administration deaktiviert",
    "Disable-user-theming should be true or false" : "Benutzer-Design deaktivieren sollte wahr oder falsch sein",
    "The primary color is used for highlighting elements like important buttons. It might get slightly adjusted depending on the current color schema." : "Die Primärfarbe wird zum Hervorheben von Elementen wie wichtigen Schaltflächen verwendet. Sie kann je nach aktuellem Farbschema leicht angepasst werden.",
    "Header logo" : "Kopfbereichs-Logo",
    "Upload new header logo" : "Neues Logo für den Kopfbereich hochladen",
    "Upload new favicon" : "Neues Favicon hochladen",
    "User settings" : "Benutzer-Einstellungen",
    "Instead of a background image you can also configure a plain background color. If you use a background image changing this color will influence the color of the app menu icons." : "Anstelle eines Hintergrundbildes können Sie auch eine einfache Hintergrundfarbe konfigurieren. Wenn Sie ein Hintergrundbild verwenden, wirkt sich die Änderung dieser Farbe auf die Farbe der App-Menüsymbole aus.",
    "Upload new logo" : "Neues Logo hochladen",
    "Upload new background and login image" : "Ein neues Hintergrund- und Anmeldebild hochladen",
    "Background and login image" : "Hintergrund und Anmeldebild",
    "Advanced options" : "Erweiterte Optionen",
    "Install the ImageMagick PHP extension with support for SVG images to automatically generate favicons based on the uploaded logo and color." : "Installieren Sie die ImageMagick PHP-Erweiterung mit Unterstützung für SVG-Bilder, um automatisch Favicons auf Basis des hochgeladenen Logos und der Farbe zu erstellen.",
    "Universal access is very important to us. We follow web standards and check to make everything usable also without mouse, and assistive software such as screenreaders. We aim to be compliant with the {guidelines}Web Content Accessibility Guidelines{linkend} 2.1 on AA level, with the high contrast theme even on AAA level." : "Der barrierefreie Zugang ist für uns sehr wichtig. Wir halten uns an Webstandards und prüfen, ob alles auch ohne Maus und unterstützende Software wie Screenreader nutzbar ist. Wir streben die Einhaltung der {guidelines}Web Content Accessibility Guidelines{linkend} 2.1 auf AA-Niveau an, mit dem kontrastreichen Design sogar auf AAA-Niveau.",
    ". Unable to apply the setting." : ". Fehler beim Anwenden der Einstellung.",
    "No background has been selected" : "Es wurde kein Hintergrund ausgewählt",
    "Select a custom color" : "Eine benutzerdefinierte Farbe auswählen",
    "Upload" : "Hochladen"
},
"nplurals=2; plural=(n != 1);");
